@@ -12,13 +12,23 @@ pub trait LTVObjectGroup<'a, const ED: ByteOrder>: Sized {
 
 pub trait LTVItem<const ED: ByteOrder> {
     type Item: LTVItem<ED>;
-    fn from_ltv(field_type: usize, data: &[u8]) -> LTVResult<Self::Item>;
+    fn from_ltv(field_type: u8, data: &[u8]) -> LTVResult<Self::Item>;
     fn to_ltv(&self) -> Vec<u8>;
 }
 
-pub trait LTVObject<'a, const ED: ByteOrder, const LENGTH_BYTE: usize, const OBJECT_ID: u8>:
+pub trait LTVObjectConvertable<'a, const ED: ByteOrder, const LENGTH_BYTE: usize>: LTVItem<ED>{
+    fn from_ltv_object(data: &'a [u8]) -> LTVResult<Self::Item>;
+    fn to_ltv_object(&self) -> Vec<u8>;
+}
+
+pub trait LTVObject<'a, const ED: ByteOrder, const LENGTH_BYTE: usize>:
     LTVItem<ED>
 {
+    const OBJECT_ID: u8;
+    
+}
+
+impl <'a, T: LTVObject<'a, ED, LENGTH_BYTE>, const ED: ByteOrder, const LENGTH_BYTE: usize> LTVObjectConvertable<'a, ED, LENGTH_BYTE> for T {
     fn from_ltv_object(data: &'a [u8]) -> LTVResult<Self::Item> {
         use crate::reader::LTVReader;
         let (_, obj_id, data) = LTVReader::<'a, ED, LENGTH_BYTE>::parse_ltv(data)?;
@@ -42,32 +52,37 @@ pub trait LTVObject<'a, const ED: ByteOrder, const LENGTH_BYTE: usize, const OBJ
             _ => panic!("Unsupported length byte {}", LENGTH_BYTE),
         };
 
-        //ED::write_u16(&mut out_ltv, (data.len() + 1) as u16),
-        out_ltv.push(OBJECT_ID);
+        out_ltv.push(Self::OBJECT_ID);
         out_ltv.append(&mut data);
 
         out_ltv
     }
 }
 
+
+
 impl<'a, T: LTVItem<ED>, const ED: ByteOrder> LTVItem<ED> for Option<T> {
     type Item = Option<T::Item>;
-    fn from_ltv(field_id: usize, data: &'_ [u8]) -> LTVResult<Self::Item> {
-        match T::from_ltv(field_id, data) {
-            Ok(e) => Ok(Some(e)),
-            Err(LTVError::NotFound(_)) => Ok(None),
-            Err(e) => return Err(e),
+    fn from_ltv(field_id: u8, data: &'_ [u8]) -> LTVResult<Self::Item> {
+        if data.len() == 0{
+            return Ok(None)
+        }else{
+            Ok(Some(T::from_ltv(field_id, data)?))
         }
     }
 
     fn to_ltv(&self) -> Vec<u8> {
-        Vec::new()
+        if let Some(e) = self {
+            e.to_ltv()
+        }else{
+            Vec::new()
+        }
     }
 }
 
 impl<const ED: ByteOrder> LTVItem<ED> for Vec<u8> {
     type Item = Self;
-    fn from_ltv(_field_id: usize, data: &[u8]) -> LTVResult<Self> {
+    fn from_ltv(_field_id: u8, data: &[u8]) -> LTVResult<Self> {
         Ok(Vec::from(data))
     }
 
@@ -76,13 +91,29 @@ impl<const ED: ByteOrder> LTVItem<ED> for Vec<u8> {
     }
 }
 
+
+impl<const ED: ByteOrder, const LENGTH: usize> LTVItem<ED> for [u8;LENGTH] {
+    type Item = Self;
+    fn from_ltv(field_id: u8, data: &[u8]) -> LTVResult<Self> {
+        data.try_into().map_err(|_| LTVError::WrongSize {
+            field_id: field_id,
+            expected: LENGTH,
+            recieved: data.len(),
+        })
+    }
+
+    fn to_ltv(&self) -> Vec<u8> {
+        (self as &[_]).into()
+    }
+}
+
 macro_rules! impl_numeric_ltvitem {
     ($($i:ident),+) => {
     $(
 
     impl<const ED: ByteOrder> LTVItem<ED> for $i {
         type Item = $i;
-        fn from_ltv(field_id: usize, data: &[u8]) -> LTVResult<Self> {
+        fn from_ltv(field_id: u8, data: &[u8]) -> LTVResult<Self> {
             let numeric_value= data
                 .try_into()
                 .and_then(|b| Ok(match ED {
@@ -124,71 +155,3 @@ impl_numeric_ltvitem! {
     u128,
     i128
 }
-
-/*
-impl LTVItem<'_,  {ByteOrder::BE}> for u8 {
-    type Item = u8;
-    fn from_ltv(field_id: usize, data: &[u8]) -> LTVResult<Self> {
-        match data.try_into().and_then(|b| Ok(u8::from_be_bytes(b))){
-            Ok(b) => Ok(b),
-            Err(e) => Err(LTVError::WrongSize {
-                field_id: field_id,
-                expected: (u8::BITS/8) as usize,
-                recieved: data.len(),
-            })
-        }
-    }
-
-    fn to_ltv(&self) -> Vec<u8> {
-        Vec::from(u8::to_le_bytes(*self))
-    }
-}
-
-impl LTVItem<'_,  {ByteOrder::LE}> for u8 {
-    type Item = u8;
-    fn from_ltv(field_id: usize, data: &[u8]) -> LTVResult<Self> {
-        match data.try_into().and_then(|b| Ok(u8::from_le_bytes(b))){
-            Ok(b) => Ok(b),
-            Err(e) => Err(LTVError::WrongSize {
-                field_id: field_id,
-                expected: (u8::BITS/8) as usize,
-                recieved: data.len(),
-            })
-        }
-    }
-
-    fn to_ltv(&self) -> Vec<u8> {
-        Vec::from(u8::to_le_bytes(*self))
-    }
-}
-
-impl<const ED: ByteOrder> LTVItem<'_,  ED> for u8 {
-    type Item = u8;
-    fn from_ltv(field_id: usize, data: &[u8]) -> LTVResult<Self> {
-        let numeric_value= data
-            .try_into()
-            .and_then(|b| Ok(match ED {
-                ByteOrder::LE=> u8::from_le_bytes(b),
-                ByteOrder::BE=> u8::from_be_bytes(b),
-            }));
-
-        match numeric_value {
-            Ok(b) => Ok(b),
-            Err(e) => Err(LTVError::WrongSize {
-                field_id: field_id,
-                expected: (u8::BITS/8) as usize,
-                recieved: data.len(),
-            })
-        }
-    }
-    fn to_ltv(&self) -> Vec<u8> {
-        Vec::from(
-            match ED {
-                ByteOrder::LE=> u8::to_le_bytes(*self),
-                ByteOrder::BE=> u8::to_be_bytes(*self),
-            }
-        )
-    }
-}
-
-*/
